Function libnotcurses_sys::c_api::ffi::fopen

source ·
pub unsafe extern "C" fn fopen(
    __filename: *const c_char,
    __modes: *const c_char
) -> *mut FILE
Open a file and create a new stream for it.

This function is a possible cancellation point and therefore not marked with __THROW.