Function libnotcurses_sys::c_api::ffi::fputc

source ·
pub unsafe extern "C" fn fputc(
    __c: c_int,
    __stream: *mut FILE
) -> c_int
Write a character to STREAM.

These functions are possible cancellation points and therefore not marked with __THROW.

These functions is a possible cancellation point and therefore not marked with __THROW.