Function libnotcurses_sys::c_api::ffi::freopen
source · pub unsafe extern "C" fn freopen(
__filename: *const c_char,
__modes: *const c_char,
__stream: *mut FILE
) -> *mut FILEExpand description
Open a file, replacing an existing stream with it.
This function is a possible cancellation point and therefore not marked with __THROW.