Function libnotcurses_sys::c_api::ffi::ncmenu_rollup
source · pub unsafe extern "C" fn ncmenu_rollup(n: *mut ncmenu) -> c_intExpand description
Roll up any unrolled menu section, and hide the menu if using hiding.
pub unsafe extern "C" fn ncmenu_rollup(n: *mut ncmenu) -> c_intRoll up any unrolled menu section, and hide the menu if using hiding.