Function libnotcurses_sys::c_api::ffi::ncplane_destroy [−][src]
Destroy the specified ncplane. None of its contents will be visible after the next call to notcurses_render(). It is an error to attempt to destroy the standard plane.