Function libnotcurses_sys::c_api::ffi::nctabbed_separator_width [−][src]
Returns the tab separator width, or zero if there is no separator.
Returns the tab separator width, or zero if there is no separator.