Function libnotcurses_sys::c_api::ffi::ncvisual_destroy
source · pub unsafe extern "C" fn ncvisual_destroy(ncv: *mut ncvisual)Expand description
Destroy an ncvisual. Rendered elements will not be disrupted, but the visual can be neither decoded nor rendered any further.