Function libnotcurses_sys::c_api::ffi::notcurses_cursor_disable [−][src]
Disable the hardware cursor. It is an error to call this while the cursor is already disabled.
Disable the hardware cursor. It is an error to call this while the cursor is already disabled.