Function libnotcurses_sys::c_api::ffi::pclose
source · pub unsafe extern "C" fn pclose(__stream: *mut FILE) -> c_intExpand description
Close a stream opened by popen and return the status of its child.
This function is a possible cancellation point and therefore not marked with __THROW.