Function libnotcurses_sys::c_api::ffi::popen

source ·
pub unsafe extern "C" fn popen(
    __command: *const c_char,
    __modes: *const c_char
) -> *mut FILE
Create a new stream connected to a pipe running the given command.

This function is a possible cancellation point and therefore not marked with __THROW.