Function libnotcurses_sys::c_api::ffi::puts

source ·
pub unsafe extern "C" fn puts(__s: *const c_char) -> c_int
Write a string, followed by a newline, to stdout.

This function is a possible cancellation point and therefore not marked with __THROW.