Function libnotcurses_sys::c_api::ffi::quick_exit
source · pub unsafe extern "C" fn quick_exit(__status: c_int)Expand description
Call all functions registered with `at_quick_exit’ in the reverse of the order in which they were registered and terminate program execution with STATUS.