Function libnotcurses_sys::c_api::ffi::realloc
source · pub unsafe extern "C" fn realloc(
__ptr: *mut c_void,
__size: c_ulong
) -> *mut c_voidExpand description
Re-allocate the previously allocated block in PTR, making the new block SIZE bytes long. */ the same pointer that was passed to it, aliasing needs to be allowed between objects pointed by the old and new pointers.