Struct libnotcurses_sys::c_api::ffi::__sigset_t
source · [−]Fields
__val: [c_ulong; 16]Trait Implementations
sourceimpl Clone for __sigset_t
impl Clone for __sigset_t
sourcefn clone(&self) -> __sigset_t
fn clone(&self) -> __sigset_t
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for __sigset_t
impl Debug for __sigset_t
sourceimpl Default for __sigset_t
impl Default for __sigset_t
sourcefn default() -> __sigset_t
fn default() -> __sigset_t
Returns the “default value” for a type. Read more
sourceimpl Hash for __sigset_t
impl Hash for __sigset_t
sourceimpl Ord for __sigset_t
impl Ord for __sigset_t
sourceimpl PartialEq<__sigset_t> for __sigset_t
impl PartialEq<__sigset_t> for __sigset_t
sourcefn eq(&self, other: &__sigset_t) -> bool
fn eq(&self, other: &__sigset_t) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &__sigset_t) -> bool
fn ne(&self, other: &__sigset_t) -> bool
This method tests for !=.
sourceimpl PartialOrd<__sigset_t> for __sigset_t
impl PartialOrd<__sigset_t> for __sigset_t
sourcefn partial_cmp(&self, other: &__sigset_t) -> Option<Ordering>
fn partial_cmp(&self, other: &__sigset_t) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for __sigset_t
impl Eq for __sigset_t
impl StructuralEq for __sigset_t
impl StructuralPartialEq for __sigset_t