Struct libnotcurses_sys::c_api::ffi::cmsghdr
source · #[repr(C)]pub struct cmsghdr {
pub cmsg_len: usize,
pub cmsg_level: c_int,
pub cmsg_type: c_int,
pub __cmsg_data: __IncompleteArrayField<c_uchar>,
}Expand description
Structure used for storage of ancillary data object information.
Fields
cmsg_len: usizeLength of data in cmsg_data plus length of cmsghdr structure. The type should be socklen_t but the definition of the kernel is incompatible with this.
cmsg_level: c_intOriginating protocol.
cmsg_type: c_intProtocol specific type.
__cmsg_data: __IncompleteArrayField<c_uchar>Ancillary data.