#[repr(C)]pub struct in_addr {
pub s_addr: in_addr_t,
}Fields
s_addr: in_addr_tTrait Implementations
sourceimpl Ord for in_addr
impl Ord for in_addr
sourceimpl PartialOrd<in_addr> for in_addr
impl PartialOrd<in_addr> for in_addr
sourcefn partial_cmp(&self, other: &in_addr) -> Option<Ordering>
fn partial_cmp(&self, other: &in_addr) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for in_addr
impl Eq for in_addr
impl StructuralEq for in_addr
impl StructuralPartialEq for in_addr