#[repr(C)]
pub struct ncplane_options { pub y: c_int, pub x: c_int, pub rows: c_uint, pub cols: c_uint, pub userptr: *mut c_void, pub name: *const c_char, pub resizecb: Option<unsafe extern "C" fn(arg1: *mut ncplane) -> c_int>, pub flags: u64, pub margin_b: c_uint, pub margin_r: c_uint, }

Fields

y: c_int

vertical placement relative to parent plane

x: c_int

horizontal placement relative to parent plane

rows: c_uint

rows, must be >0 unless NCPLANE_OPTION_MARGINALIZED

cols: c_uint

columns, must be >0 unless NCPLANE_OPTION_MARGINALIZED

userptr: *mut c_void

user curry, may be NULL

name: *const c_char

name (used only for debugging), may be NULL

resizecb: Option<unsafe extern "C" fn(arg1: *mut ncplane) -> c_int>

callback when parent is resized

flags: u64

closure over NCPLANE_OPTION_*

margin_b: c_uint

margins (require NCPLANE_OPTION_MARGINALIZED)

margin_r: c_uint

margins (require NCPLANE_OPTION_MARGINALIZED)

Implementations

New NcPlaneOptions using the horizontal x.

Returns a default NcPlane options builder.

Returns a builder object from the current NcPlane options.

New NcPlaneOptions with horizontal alignment.

New NcPlaneOptions, with flags.

New NcPlaneOptions, with flags and horizontal alignment.

Note: Already includes the NcPlaneOptions::HORALIGNED flag.

Returns true if it has the VerAligned flag set.

Returns true if it has the HorAligned flag set.

Returns true if it has the Marginalized flag set.

Returns true if it has the Fixed flag set.

Returns true if it has the AutoGrow flag set.

Returns true if it has the VScroll flag set.