#[repr(C)]
pub struct ncplot_options { pub maxchannels: u64, pub minchannels: u64, pub legendstyle: u16, pub gridtype: ncblitter_e, pub rangex: c_int, pub title: *const c_char, pub flags: u64, }

Fields

maxchannels: u64

channels for the maximum and minimum levels. linear or exponential interpolation will be applied across the domain between these two.

minchannels: u64legendstyle: u16

styling used for the legend, if NCPLOT_OPTION_LABELTICKSD is set

gridtype: ncblitter_e

number of “pixels” per row x column

rangex: c_int

independent variable can either be a contiguous range, or a finite set of keys. for a time range, say the previous hour sampled with second resolution, the independent variable would be the range [0..3600): 3600. if rangex is 0, it is dynamically set to the number of columns.

title: *const c_char

optional, printed by the labels

flags: u64

bitfield over NCPLOT_OPTION_*

Implementations

source

impl ncplot_options

source

pub const DETECTMAXONLY: u32 = 16u32

Use domain detection only for max

source

pub const EXPONENTIALD: u32 = 2u32

Exponential dependent axis

source

pub const LABELTICKSD: u32 = 1u32

Show labels for dependent axis

source

pub const NODEGRADE: u32 = 8u32

Use domain detection only for max

source

pub const VERTICALI: u32 = 4u32

Independent axis is vertical