Type Definition libnotcurses_sys::c_api::ffi::ncstreamcb
source · pub type ncstreamcb = Option<unsafe extern "C" fn(arg1: *mut ncvisual, arg2: *mut ncvisual_options, arg3: *const timespec, arg4: *mut c_void) -> c_int>;Expand description
Called for each frame rendered from ‘ncv’. If anything but 0 is returned, the streaming operation ceases immediately, and that value is propagated out. The recommended absolute display time target is passed in ‘tspec’.