Type Definition libnotcurses_sys::c_api::ffi::tabletcb

source ·
pub type tabletcb = Option<unsafe extern "C" fn(t: *mut nctablet, drawfromtop: bool) -> c_int>;
Tablet draw callback, provided a tablet (from which the ncplane and userptr may be extracted), and a bool indicating whether output ought be drawn from the top (true) or bottom (false). Returns non-negative count of output lines, which must be less than or equal to ncplane_dim_y(nctablet_plane(t)).