pub unsafe extern "C" fn ncdirect_cursor_push(
    n: *mut ncdirect
) -> c_int
Push or pop the cursor location to the terminal’s stack. The depth of this stack, and indeed its existence, is terminal-dependent.