Function libnotcurses_sys::c_api::ncdirect_inputready_fd
source · [−]Expand description
Get a file descriptor suitable for input event poll()ing. When this descriptor becomes available, you can call ncdirect_get_nblock(), and input ought be ready. This file descriptor is not necessarily the file descriptor associated with stdin (but it might be!).