Function libnotcurses_sys::c_api::ncmenu_nextitem
source · [−]Expand description
Move to the previous/next item within the currently unrolled section. If no section is unrolled, the first section will be unrolled.
Move to the previous/next item within the currently unrolled section. If no section is unrolled, the first section will be unrolled.