Function libnotcurses_sys::c_api::ncmenu_nextsection [−][src]
Unroll the previous/next section (relative to current unrolled). If no section is unrolled, the first section will be unrolled.
Unroll the previous/next section (relative to current unrolled). If no section is unrolled, the first section will be unrolled.