Function libnotcurses_sys::c_api::ncmenu_unroll
source · pub unsafe extern "C" fn ncmenu_unroll(
n: *mut ncmenu,
sectionidx: c_int
) -> c_intExpand description
Unroll the specified menu section, making the menu visible if it was invisible, and rolling up any menu section that is already unrolled.