Function libnotcurses_sys::c_api::ncpile_bottom
source · pub unsafe extern "C" fn ncpile_bottom(
n: *mut ncplane
) -> *mut ncplaneExpand description
Return the bottommost plane of the pile containing ‘n’.
pub unsafe extern "C" fn ncpile_bottom(
n: *mut ncplane
) -> *mut ncplaneReturn the bottommost plane of the pile containing ‘n’.