pub unsafe extern "C" fn ncpile_render_to_file(
    p: *mut ncplane,
    fp: *mut FILE
) -> c_int
Write the last rendered frame, in its entirety, to ‘fp’. If a frame has not yet been rendered, nothing will be written.