Function libnotcurses_sys::c_api::ncpile_top
source · pub unsafe extern "C" fn ncpile_top(n: *mut ncplane) -> *mut ncplaneExpand description
Return the topmost plane of the pile containing ‘n’.
pub unsafe extern "C" fn ncpile_top(n: *mut ncplane) -> *mut ncplaneReturn the topmost plane of the pile containing ‘n’.