Function libnotcurses_sys::c_api::ncplane_cursor_y
source · pub fn ncplane_cursor_y(plane: &NcPlane) -> u32Expand description
Returns the current row of the cursor within this NcPlane.
Method: NcPlane.gradient().
pub fn ncplane_cursor_y(plane: &NcPlane) -> u32Returns the current row of the cursor within this NcPlane.
Method: NcPlane.gradient().