pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcResult_i32
Replaces the NcCell at the current location with the provided char, using the current style.
NcCell
char
On success, returns the number of columns the cursor was advanced.
If the glyph can not fit in the current line, it is an error, unless scrolling is enabled.
Method: NcPlane.putchar().