Function libnotcurses_sys::c_api::ncplane_putegc
source · pub fn ncplane_putegc(
plane: &mut NcPlane,
egc: &str,
sbytes: Option<&mut usize>
) -> NcResult_i32Expand description
Replaces the NcCell at the current location with the provided egc,
using the current style.
Advances the cursor by the width of the cluster (but not past the end of the the plane), and this number is returned on success.
The number of bytes converted from the egc can be optionally written to
sbytes.
If the glyph can not fit in the current line, it is an error, unless scrolling is enabled.
Method: NcPlane.putegc().