Function libnotcurses_sys::c_api::ncplane_set_styles
source · [−]Expand description
Set the specified style bits for the ncplane ‘n’, whether they’re actively supported or not.
Set the specified style bits for the ncplane ‘n’, whether they’re actively supported or not.