Function libnotcurses_sys::c_api::ncplane_set_userptr
source · [−]Expand description
Manipulate the opaque user pointer associated with this plane. ncplane_set_userptr() returns the previous userptr after replacing it with ‘opaque’. the others simply return the userptr.