Function libnotcurses_sys::c_api::ncreader_clear
source · pub unsafe extern "C" fn ncreader_clear(n: *mut ncreader) -> c_intExpand description
empty the ncreader of any user input, and home the cursor.
pub unsafe extern "C" fn ncreader_clear(n: *mut ncreader) -> c_intempty the ncreader of any user input, and home the cursor.