Function libnotcurses_sys::c_api::ncreader_offer_input
source · [−]Expand description
Offer the input to the ncreader. If it’s relevant, this function returns true, and the input ought not be processed further. Almost all inputs are relevant to an ncreader, save synthesized ones.