Function libnotcurses_sys::c_api::ncreel_add
source · pub unsafe extern "C" fn ncreel_add(
nr: *mut ncreel,
after: *mut nctablet,
before: *mut nctablet,
cb: tabletcb,
opaque: *mut c_void
) -> *mut nctabletExpand description
Add a new nctablet to the provided ncreel ‘nr’, having the callback object ‘opaque’. Neither, either, or both of ‘after’ and ‘before’ may be specified. If neither is specified, the new tablet can be added anywhere on the reel. If one or the other is specified, the tablet will be added before or after the specified tablet. If both are specified, the tablet will be added to the resulting location, assuming it is valid (after->next == before->prev); if it is not valid, or there is any other error, NULL will be returned.