pub unsafe extern "C" fn ncreel_focused(
    nr: *mut ncreel
) -> *mut nctablet
Return the focused tablet, if any tablets are present. This is not a copy; be careful to use it only for the duration of a critical section.