Function libnotcurses_sys::c_api::ncreel_next
source · pub unsafe extern "C" fn ncreel_next(nr: *mut ncreel) -> *mut nctabletExpand description
Change focus to the next tablet, if one exists
pub unsafe extern "C" fn ncreel_next(nr: *mut ncreel) -> *mut nctabletChange focus to the next tablet, if one exists