Function libnotcurses_sys::c_api::ncreel_prev
source · pub unsafe extern "C" fn ncreel_prev(nr: *mut ncreel) -> *mut nctabletExpand description
Change focus to the previous tablet, if one exists
pub unsafe extern "C" fn ncreel_prev(nr: *mut ncreel) -> *mut nctabletChange focus to the previous tablet, if one exists