Function libnotcurses_sys::c_api::ncreel_tabletcount
source · pub unsafe extern "C" fn ncreel_tabletcount(
nr: *const ncreel
) -> c_intExpand description
Return the number of nctablets in the ncreel ‘nr’.
pub unsafe extern "C" fn ncreel_tabletcount(
nr: *const ncreel
) -> c_intReturn the number of nctablets in the ncreel ‘nr’.