Function libnotcurses_sys::c_api::nctab_name
source · pub unsafe extern "C" fn nctab_name(t: *mut nctab) -> *const c_charExpand description
Returns the tab name. This is not a copy and it should not be stored.
pub unsafe extern "C" fn nctab_name(t: *mut nctab) -> *const c_charReturns the tab name. This is not a copy and it should not be stored.