Function libnotcurses_sys::c_api::nctabbed_next
source · [−]Expand description
Select the tab after the currently selected tab, and return the newly selected tab. Returns NULL if there are no tabs.
Select the tab after the currently selected tab, and return the newly selected tab. Returns NULL if there are no tabs.