Function libnotcurses_sys::c_api::nctabbed_separator_width
source · [−]Expand description
Returns the tab separator width, or zero if there is no separator.
Returns the tab separator width, or zero if there is no separator.