Function libnotcurses_sys::c_api::nctree_focused
source · pub unsafe extern "C" fn nctree_focused(n: *mut nctree) -> *mut c_voidExpand description
Return the focused item, if any items are present. This is not a copy; be careful to use it only for the duration of a critical section.