Function libnotcurses_sys::c_api::nctree_redraw
source · pub unsafe extern "C" fn nctree_redraw(n: *mut nctree) -> c_intExpand description
Redraw the nctree ‘n’ in its entirety. The tree will be cleared, and items will be lain out, using the focused item as a fulcrum. Item-drawing callbacks will be invoked for each visible item.