Function libnotcurses_sys::c_api::ncvisual_rotate
source · [−]Expand description
Rotate the visual ‘rads’ radians. Only M_PI/2 and -M_PI/2 are supported at the moment, but this might change in the future.
Rotate the visual ‘rads’ radians. Only M_PI/2 and -M_PI/2 are supported at the moment, but this might change in the future.