Function libnotcurses_sys::c_api::notcurses_canhalfblock
source · [−]Expand description
Returns true if we can reliably use Unicode half blocks.
Method: Nc.canhalfblock().
Returns true if we can reliably use Unicode half blocks.
Method: Nc.canhalfblock().