Function libnotcurses_sys::c_api::notcurses_cursor_disable
source · [−]Expand description
Disable the hardware cursor. It is an error to call this while the cursor is already disabled.
Disable the hardware cursor. It is an error to call this while the cursor is already disabled.