Function libnotcurses_sys::c_api::notcurses_default_background
source · [−]Expand description
Get the default background color, if it is known. Returns -1 on error (unknown background). On success, returns 0, writing the RGB value to ‘bg’ (if non-NULL) and setting ‘bgtrans’ high iff the background color is treated as transparent.