pub unsafe extern "C" fn notcurses_inputready_fd(
    n: *mut notcurses
) -> c_int
Get a file descriptor suitable for input event poll()ing. When this descriptor becomes available, you can call notcurses_get_nblock(), and input ought be ready. This file descriptor is not necessarily the file descriptor associated with stdin (but it might be!).