Function libnotcurses_sys::c_api::notcurses_render
source · pub fn notcurses_render(nc: &mut Nc) -> NcResult_i32Expand description
Renders and rasterizes the standard pile in one shot. Blocking call.
Method: Nc.render().
pub fn notcurses_render(nc: &mut Nc) -> NcResult_i32Renders and rasterizes the standard pile in one shot. Blocking call.
Method: Nc.render().