Struct libnotcurses_sys::c_api::ncinput
source · pub struct ncinput {
pub id: u32,
pub y: c_int,
pub x: c_int,
pub utf8: [c_char; 5],
pub alt: bool,
pub shift: bool,
pub ctrl: bool,
pub evtype: ncintype_e,
pub modifiers: c_uint,
pub ypx: c_int,
pub xpx: c_int,
}Expand description
An input event. Cell coordinates are currently defined only for mouse events. It is not guaranteed that we can set the modifiers for a given ncinput. We encompass single Unicode codepoints, not complete EGCs. FIXME for abi4, combine the bools into |modifiers|
Fields
id: u32Unicode codepoint or synthesized NCKEY event
y: c_inty/x cell coordinate of event, -1 for undefined
x: c_inty/x cell coordinate of event, -1 for undefined
utf8: [c_char; 5]utf8 representation, if one exists
alt: boolwas alt held?
shift: boolwas shift held?
ctrl: boolwas ctrl held?
evtype: ncintype_eEND DEPRECATION
modifiers: c_uintbitmask over NCKEY_MOD_*
ypx: c_intpixel offsets within cell, -1 for undefined
xpx: c_intpixel offsets within cell, -1 for undefined
Implementations
sourceimpl ncinput
impl ncinput
sourcepub fn with_shift(id: char) -> NcInput
pub fn with_shift(id: char) -> NcInput
New NcInput with shift key.
sourcepub fn with_all_args(
id: char,
x: Option<u32>,
y: Option<u32>,
modifiers: NcKeyMod,
evtype: NcInputType
) -> NcInput
pub fn with_all_args( id: char, x: Option<u32>, y: Option<u32>, modifiers: NcKeyMod, evtype: NcInputType ) -> NcInput
New NcInput, expecting all the arguments (except utf8).
sourceimpl ncinput
impl ncinput
sourcepub fn nomod_p(&self) -> bool
pub fn nomod_p(&self) -> bool
Returns true if there are no modifiers present.
C style function: ncinput_nomod_p().
sourcepub fn shift_p(&self) -> bool
pub fn shift_p(&self) -> bool
Returns true if the Shift modifier is present.
C style function: ncinput_shift_p().
sourcepub fn alt_p(&self) -> bool
pub fn alt_p(&self) -> bool
Returns true if the Alt modifier is present.
C style function: ncinput_alt_p().
sourcepub fn ctrl_p(&self) -> bool
pub fn ctrl_p(&self) -> bool
Returns true if the Ctrl modifier is present.
C style function: ncinput_ctrl_p().
sourcepub fn meta_p(&self) -> bool
pub fn meta_p(&self) -> bool
Returns true if the Meta modifier is present.
C style function: ncinput_meta_p().
sourcepub fn super_p(&self) -> bool
pub fn super_p(&self) -> bool
Returns true if the Super modifier is present.
C style function: ncinput_super_p().
sourcepub fn hyper_p(&self) -> bool
pub fn hyper_p(&self) -> bool
Returns true if the Hyper modifier is present.
C style function: ncinput_hyper_p().
sourcepub fn capslock_p(&self) -> bool
pub fn capslock_p(&self) -> bool
Returns true if the CapsLock modifier is present.
C style function: ncinput_capslock_p().
sourcepub fn numlock_p(&self) -> bool
pub fn numlock_p(&self) -> bool
Returns true if the NumLock modifier is present.
C style function: ncinput_numlock_p().
sourcepub fn equal_p(&self, other: &NcInput) -> bool
pub fn equal_p(&self, other: &NcInput) -> bool
Returns true if both NcInputs are equal.
C style function: ncinput_equal_p().