#[repr(C)]
pub struct ncmenu_item { pub desc: *const c_char, pub shortcut: ncinput, }
Menus. Horizontal menu bars are supported, on the top and/or bottom rows. If the menu bar is longer than the screen, it will be only partially visible. Menus may be either visible or invisible by default. In the event of a plane resize, menus will be automatically moved/resized. Elements can be dynamically enabled or disabled at all levels (menu, section, and item),

Fields

desc: *const c_char

utf-8 menu item, NULL for horizontal separator

shortcut: ncinput

shortcut, all should be distinct

Implementations

New NcMenuItem for NcMenu.

New empty NcMenuItem for NcMenu.