Struct libnotcurses_sys::c_api::ncmenu_options [−][src]
#[repr(C)]pub struct ncmenu_options {
pub sections: *mut ncmenu_section,
pub sectioncount: c_int,
pub headerchannels: u64,
pub sectionchannels: u64,
pub flags: u64,
}Fields
sections: *mut ncmenu_sectionarray of ‘sectioncount’ menu_sections
sectioncount: c_intmust be positive
headerchannels: u64styling for header
sectionchannels: u64styling for sections
flags: u64flag word of NCMENU_OPTION_*
Implementations
New NcMenuOptions for NcMenu.
sections must contain at least 1 NcMenuSection.
pub fn with_all_args(
sections: &mut [NcMenuSection],
style_header: NcChannels,
style_sections: NcChannels,
flags: u64
) -> Self
pub fn with_all_args(
sections: &mut [NcMenuSection],
style_header: NcChannels,
style_sections: NcChannels,
flags: u64
) -> Self
New NcMenuOptions for NcMenu, with all args.
sections must contain at least 1 NcMenuSection.
Returns the styling for the header.
(No equivalent C style function)
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
Returns the styling for the sections.
(No equivalent C style function)
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
NcMenuOptions flag: Bottom row (as opposed to top row).
NcMenuOptions flag: Hides the menu when not unrolled.