Struct libnotcurses_sys::c_api::ncmselector_item
source · pub struct ncmselector_item {
pub option: *const c_char,
pub desc: *const c_char,
pub selected: bool,
}Fields
option: *const c_chardesc: *const c_charselected: boolTrait Implementations
sourceimpl Debug for ncmselector_item
impl Debug for ncmselector_item
sourceimpl Default for ncmselector_item
impl Default for ncmselector_item
sourceimpl Hash for ncmselector_item
impl Hash for ncmselector_item
sourceimpl Ord for ncmselector_item
impl Ord for ncmselector_item
sourcefn cmp(&self, other: &ncmselector_item) -> Ordering
fn cmp(&self, other: &ncmselector_item) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<ncmselector_item> for ncmselector_item
impl PartialEq<ncmselector_item> for ncmselector_item
sourcefn eq(&self, other: &ncmselector_item) -> bool
fn eq(&self, other: &ncmselector_item) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<ncmselector_item> for ncmselector_item
impl PartialOrd<ncmselector_item> for ncmselector_item
sourcefn partial_cmp(&self, other: &ncmselector_item) -> Option<Ordering>
fn partial_cmp(&self, other: &ncmselector_item) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more