Struct libnotcurses_sys::c_api::ncplane_options[][src]

#[repr(C)]
pub struct ncplane_options { pub y: c_int, pub x: c_int, pub rows: c_uint, pub cols: c_uint, pub userptr: *mut c_void, pub name: *const c_char, pub resizecb: Option<unsafe extern "C" fn(arg1: *mut ncplane) -> c_int>, pub flags: u64, pub margin_b: c_uint, pub margin_r: c_uint, }

Fields

y: c_int

vertical placement relative to parent plane

x: c_int

horizontal placement relative to parent plane

rows: c_uint

rows, must be >0 unless NCPLANE_OPTION_MARGINALIZED

cols: c_uint

columns, must be >0 unless NCPLANE_OPTION_MARGINALIZED

userptr: *mut c_void

user curry, may be NULL

name: *const c_char

name (used only for debugging), may be NULL

resizecb: Option<unsafe extern "C" fn(arg1: *mut ncplane) -> c_int>

callback when parent is resized

flags: u64

closure over NCPLANE_OPTION_*

margin_b: c_uint

margins (require NCPLANE_OPTION_MARGINALIZED)

margin_r: c_uint

margins (require NCPLANE_OPTION_MARGINALIZED)

Implementations

Horizontal alignment relative to the parent plane. Use NcAlign for ‘x’.

Vertical alignment relative to the parent plane. Use NcAlign for ‘y’.

Maximize relative to the parent plane, modulo the provided margins.

The margins are best-effort; the plane will always be at least 1 column by 1 row. If the margins can be effected, the plane will be sized to all remaining space. ‘y’ and ‘x’ are overloaded as the top and left margins when this flag is used. ‘rows’ and ‘cols’ must be 0 when this flag is used. This flag is exclusive with both of the alignment flags.

Do not scroll alongside its parent.

If this plane is bound to a scrolling plane, it ought not scroll along with the parent (it will still move with the parent, maintaining its relative position, if the parent is moved to a new location).

Enables automatic growth of the plane to accommodate output.

Creating a plane with this flag is equivalent to immediately calling NcPlane::set_autogrow(true) following plane creation.

Enables vertical scrolling of the plane to accommodate output.

Creating a plane with this flag is equivalent to immediately calling NcPlane::set_scrolling(true) following plane creation.

New NcPlaneOptions using the horizontal x.

Returns a default builder object for NcPlaneOptions.

Returns a builder object for NcPlaneOptions from the current options.

New NcPlaneOptions with horizontal alignment.

New NcPlaneOptions, with flags.

New NcPlaneOptions, with flags and horizontal alignment.

Note: Already includes the NcPlaneOptions::HORALIGNED flag.

Returns true if it has the VERALIGNED flag set.

Returns true if it has the HORALIGNED flag set.

Returns true if it has the MARGINALIZED flag set.

Returns true if it has the FIXED flag set.

Returns true if it has the AUTOGROW flag set.

Returns true if it has the VSCROLL flag set.