#[repr(C)]
pub struct ncreel_options { pub bordermask: c_uint, pub borderchan: u64, pub tabletmask: c_uint, pub tabletchan: u64, pub focusedchan: u64, pub flags: u64, }

Fields

bordermask: c_uint

bitfield; 1s will not be drawn (see bordermaskbits)

borderchan: u64

attributes used for ncreel border

tabletmask: c_uint

bitfield; same as bordermask but for tablet borders

tabletchan: u64

tablet border styling channel

focusedchan: u64

focused tablet border styling channel

flags: u64

bitfield over NCREEL_OPTION_*

Implementations

is navigation circular (does moving down from the last tablet move to the first, and vice versa)? only meaningful when infinitescroll is true. if infinitescroll is false, this must be false.

is scrolling infinite (can one move down or up forever, or is an end reached?). if true, ‘circular’ specifies how to handle the special case of an incompletely-filled reel.