Struct libnotcurses_sys::c_api::ncselector[][src]

#[repr(C)]
pub struct ncselector { /* fields omitted */ }

Implementations

Creates a selector over a plane.

The selector will take care of destroying the plane.

Starts the builder.

Offers an input to the selector.

If it’s relevant, this function returns true, and the input ought not be processed further. If it’s irrelevant to the selector, false is returned.

Relevant inputs include:

  • a mouse click on an item.
  • a mouse scrollwheel event.
  • a mouse click on the scrolling arrows.
  • up, down, pgup, or pgdown on an unrolled menu (navigates among items).

Destroys the NcSelector.

Note that this also destroys the NcPlane.

Adds an item.

Deletes an item.

C style function: ncselector_delitem().

Returns the selected option if there is one.

C style function: ncselector_delitem().

Move down in the list. A reference to the newly-selected item is returned, or NULL if there are no items in the list.

Move up in the list. A reference to the newly-selected item is returned, or NULL if there are no items in the list.