Struct libnotcurses_sys::c_api::ncselector_item
source · pub struct ncselector_item {
pub option: *const c_char,
pub desc: *const c_char,
}Expand description
selection widget – an ncplane with a title header and a body section. the body section supports infinite scrolling up and down.
At all times, exactly one item is selected.
Fields
option: *const c_chardesc: *const c_charImplementations