Struct libnotcurses_sys::c_api::nctree[][src]

#[repr(C)]
pub struct nctree { /* fields omitted */ }

Implementations

Creates an NcTree with the specified options.

C style function: nctree_create().

Destroys an NcTree created with new().

C style function: nctree_destroy().

Inserts item at spec.

The path up to the last element must already exist. If an item already exists at the path, it will be moved to make room for item.

C style function: nctree_add().

Deletes the item at spec, including any subitems.

C style function: nctree_del().

Returns the focused item, if any items are present.

This is not a copy; be careful to use it only for the duration of a critical section.

C style function: nctree_focused().

Changes the focus to the next item, and returns it.

C style function: nctree_next().

Changes the focus to the previous item, and returns it.

C style function: nctree_prev().

Offers the input to this NcTree.

If it’s relevant, this function returns true, and the input ought not be processed further. If it’s irrelevant to the tree, false is returned.

Relevant inputs include:

  • a mouse click on an item (focuses item)
  • a mouse scrollwheel event (srolls tree)
  • up, down, pgup, or pgdown (navigates among items)

C style function: nctree_offer_input().

Returns the NcPlane backing this NcTree.

C style function: nctree_plane().

Redraws the NcTree in its entirety.

The tree will be cleared, and items will be laid out, using the focused item as a fulcrum.

Item-drawing callbacks will be invoked for each visible item.

C style function: nctree_redraw().