#[repr(C)]
pub struct notcurses_options { pub termtype: *const c_char, pub loglevel: ncloglevel_e, pub margin_t: c_uint, pub margin_r: c_uint, pub margin_b: c_uint, pub margin_l: c_uint, pub flags: u64, }
Configuration for notcurses_init().

Fields

termtype: *const c_char

The name of the terminfo database entry describing this terminal. If NULL, the environment variable TERM is used. Failure to open the terminal definition will result in failure to initialize notcurses.

loglevel: ncloglevel_e

Progressively higher log levels result in more logging to stderr. By default, nothing is printed to stderr once fullscreen service begins.

margin_t: c_uint

Desirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).

margin_r: c_uint

Desirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).

margin_b: c_uint

Desirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).

margin_l: c_uint

Desirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).

flags: u64

General flags; see NCOPTION_*. This is expressed as a bitfield so that future options can be added without reshaping the struct. Undefined bits must be set to 0.

Implementations

Returns a default Nc options builder.

Returns a builder object from the current Nc options.

New NcOptions.

New NcOptions, with margins.

New NcOptions, with flags.

New NcOptions, with flags

Returns the (top, right, bottom, left) margins.

Returns the log level.

Returns true if it has the DrainInput flag set.

Returns true if it has the InhibitSetLocale flag set.

Returns true if it has the NoAlternateScreen flag set.

Returns true if it has the NoClearBitmaps flag set.

Returns true if it has the NoFontChanges flag set.

Returns true if it has the NoQuitSigHandlers flag set.

Returns true if it has the NoWinchSigHandler flag set.

Returns true if it has the PreserveCursor flag set.

Returns true if it has the Scrolling flag set.

Returns true if it has the CliMode flag set.

Returns true if it has the SuppressBanners flag set.