NcAlpha

Enum NcAlpha 

#[repr(u32)]
pub enum NcAlpha { Blend = 268_435_456, HighContrast = 805_306_368, Opaque = 0, Transparent = 536_870_912, }
Alpha information, part of an NcChannel, applies to NcCell’s foreground or background color.

Default:

NcAlpha::Opaque

Diagram

Internally it’s 2 bits of alpha, surrounded by context dependent bits:

~~AA~~~~ -------- -------- --------

See also: NcChannels for more context information.

Variants



Blend = 268_435_456

Indicates NcCell’s foreground or background color will be a composite between its color and the NcCells’ corresponding colors underneath it.



HighContrast = 805_306_368

Indicates the foreground color will be high-contrast, relative to the computed background.

Background cannot be high-contrast.



Opaque = 0

Indicates NcCell’s foreground or background color is used unchanged.



Transparent = 536_870_912

Indicates NcCell’s foreground or background color is derived entirely from the NcCells underneath it.

Implementations

Source

impl NcAlpha

pub fn display_short(&self) -> &str

Displays the short name identifier of the alpha value.