Struct libnotcurses_sys::NcBoxMask
source · [−]#[repr(transparent)]pub struct NcBoxMask(pub NcBoxMask_u32);Expand description
A bitmask for drawing borders, gradients and corners.
Flags
GradTopGradRightGradBottomGradLeftMaskTopMaskRightMaskBottomMaskLeftCornerMaskCornerShiftNone
Default
Tuple Fields
0: NcBoxMask_u32Implementations
sourceimpl NcBoxMask
impl NcBoxMask
sourcepub const GradBottom: Self = _
pub const GradBottom: Self = _
Bottom gradient mask.
sourcepub const MaskBottom: Self = _
pub const MaskBottom: Self = _
Bottom border mask.
sourcepub const CornerMask: Self = _
pub const CornerMask: Self = _
Corner mask to control the drawing of boxes corners.
By default, vertexes are drawn whether their connecting edges are drawn or not. The value of the bits control this, and are interpreted as the number of connecting edges necessary to draw a given corner.
At 0 (the default), corners are always drawn. At 3, corners are never drawn (since at most 2 edges can touch a box’s corner).
sourcepub const CornerShift: Self = _
pub const CornerShift: Self = _
The number of bits CornerMask is shifted.