Struct libnotcurses_sys::NcPixelGeometry
source · [−]pub struct NcPixelGeometry {
pub term_y: u32,
pub term_x: u32,
pub cell_y: u32,
pub cell_x: u32,
pub max_bitmap_y: u32,
pub max_bitmap_x: u32,
}Expand description
Contains the pixel geometry information as returned by the
NcPlane.pixel_geom method.
If bitmaps are not supported, the fields max_bitmap_* will be 0.
See also NcVisualGeometry.
Fields
term_y: u32The height in pixels of the display region.
term_x: u32The width in pixels of the display region.
cell_y: u32The height in pixels of a single cell.
cell_x: u32The width in pixels of a single cell.
max_bitmap_y: u32The height in pixels of the maximum displayable bitmap (0 if not supported).
max_bitmap_x: u32The width in pixels of the maximum displayable bitmap (0 if not supported).