NcVisualFlag

Struct NcVisualFlag 

pub struct NcVisualFlag(pub NcVisualFlag_u64);
Tuple Fields

0: NcVisualFlag_u64

Implementations

Source

impl NcVisualFlag

pub const None: Self

No flags.

pub const AddAlpha: Self

Treats as transparent the color specified in the transcolor field.

pub const Blend: Self

Uses NcAlpha::Blend with the NcVisual.

pub const ChildPlane: Self

allows you to indicate that the n field of ncvisual_options refers not to the plane onto which you’d like to blit, but the parent of a new plane.

A plane will be created using the other parameters in the ncvisual_options, as a child of this parent. This means things like, say, vertically centering a sprixel relative to the standard plane can be done in one step.

pub const NoDegrade: Self

Fails rather than gracefully degrade. See NcBlitter.

pub const VerAligned: Self

Y is an alignment, not absolute.

pub const HorAligned: Self

X is an alignment, not absolute.

pub const NoInterpolate: Self

Uses non-interpolative scaling.