Struct libnotcurses_sys::NcVisualOptionsBuilder [−][src]
pub struct NcVisualOptionsBuilder<'ncplane> { /* fields omitted */ }Expand description
Builder object for NcVisualOptions.
Can be constructed by calling NcVisualOptions::builder().
Implementations
Sets the NcPlane where the blitting will be done.
This NcPlane could also be considered the parent of a new plane where
the blitting will occur by utilizing the child method.
When no NcPlane is provided, one will be created using the exact size
necessary to render the source with perfect fidelity (this might be
smaller or larger than the rendering area).
Default: None (no plane).
If true, a plane must also be provided, which will be the parent
of a new child NcPlane into which the blitting will be done.
If false, the blitting will occur in the provided plane, if any,
or in a newly created NcPlane otherwise.
Default: false (no child plaane).
Effect: Sets the CHILDPLANE flag.
Sets the NcScale.
Default: NcScale::NOSCALE.
Sets the vertical placement.
Default: 0.
Effect: Sets the y coordinate, and unsets the VERALIGNED flag.
Sets the horizontal placement.
Default: 0.
Effect: Sets the x coordinate, and unsets the HORALIGNED flag.
Sets the vertical & horizontal placement.
Default: (0, 0).
Effect: Sets the y & x coordinates and unsets the VERALIGNED
& HORALIGNED flags.
Sets the vertical alignment.
Default: NcAlign::Top.
Effect: Sets the y alignment and the VERALIGNED flag.
Sets the horizontal alignment.
Default: NcAlign::Left.
Effect: Sets the x alignment and the VERALIGNED flag.
Sets the vertical & horizontal alignments.
Default: (NcAlign::Top, NcAlign::Left).
Effect: Sets the y & x alignments and the VERALIGNED flag.
Choose the NcBlitter.
Default: NcBlitter::Default.
Choose NcBlitter::Pixel for the blitter.
Choose the color to be considered transparent, or None.
Default: none.
Efect: (Un)Sets the transparent color, and the ADDALPHA flag.
Choose whether to use NcAlpha::BLEND with the NcVisual, so that
the foreground or background colors can be a composite between
a color and the corresponding colors underneath it.
Default: false (no blend).
Effect: Sets the BLEND flag.
Choose between gracefully degrading the blitter, or fail if the choosen
NcBlitter is not supported by the terminal.
Default: true (degrades).
Effect: Sets the NODEGRADE flag.
See also: the rules of degradation.
Sets the NOINTERPOLATE flag.
Default: true (interpolates).
Sets the region to be rendered.
(start_y, start_x, len_y, len_x)
Sets the pixel offset within the NcCell.
Finishes the building and returns NcVisualOptions.