pub type NcReaderOptions = ncreader_options;
Options struct for NcReader

type in C: ncreader_options (struct)

Implementations

source

impl NcReaderOptions

source

pub const fn new() -> Self

NcReaderOptions simple constructor.

source

impl NcReaderOptions

source

pub const CURSOR: u32 = 8u32

Makes the terminal cursor visible across the lifetime of the ncreader, and have the ncreader manage the cursor’s placement.

source

pub const HORSCROLL: u32 = 1u32

Enables horizontal scrolling. Virtual lines can then grow arbitrarily long.

source

pub const NOCMDKEYS: u32 = 4u32

Disables all editing shortcuts. By default, emacs-style keys are available.

source

pub const VERSCROLL: u32 = 2u32

Enables vertical scrolling. You can then use arbitrarily many virtual lines.