pub type NcReelOptions = ncreel_options;Expand description
Options struct for NcReel
Aliased Type
#[repr(C)]pub struct NcReelOptions {
pub bordermask: u32,
pub borderchan: u64,
pub tabletmask: u32,
pub tabletchan: u64,
pub focusedchan: u64,
pub flags: u64,
}Fields
bordermask: u32bitfield; 1s will not be drawn (see bordermaskbits)
borderchan: u64attributes used for ncreel border
tabletmask: u32bitfield; same as bordermask but for tablet borders
tabletchan: u64tablet border styling channel
focusedchan: u64focused tablet border styling channel
flags: u64bitfield over NCREEL_OPTION_*
Implementations
Sourceimpl NcReelOptions
impl NcReelOptions
Sourcepub const CIRCULAR: u32 = c_api::NCREEL_OPTION_CIRCULAR
pub const CIRCULAR: u32 = c_api::NCREEL_OPTION_CIRCULAR
is navigation circular (does moving down from the last tablet move to the first, and vice versa)? only meaningful when infinitescroll is true. if infinitescroll is false, this must be false.
Sourcepub const INFINITESCROLL: u32 = c_api::NCREEL_OPTION_INFINITESCROLL
pub const INFINITESCROLL: u32 = c_api::NCREEL_OPTION_INFINITESCROLL
is scrolling infinite (can one move down or up forever, or is an end reached?). if true, ‘circular’ specifies how to handle the special case of an incompletely-filled reel.