Type Definition libnotcurses_sys::widgets::NcTabbed

source ·
pub type NcTabbed = nctabbed;
Tabbed widgets.

The tab list is displayed at the top or at the bottom of the plane, and only one tab is visible at a time.

type in C: nctabbed (struct)