Function libnotcurses_sys::c_api::ffi::exit
source · pub unsafe extern "C" fn exit(__status: c_int)Expand description
Call all functions registered with atexit' and on_exit’,
in the reverse of the order in which they were registered,
perform stdio cleanup, and terminate program execution with STATUS.