Function libnotcurses_sys::c_api::ffi::perror
source · pub unsafe extern "C" fn perror(__s: *const c_char)Expand description
Print a message describing the meaning of the value of errno.
This function is a possible cancellation point and therefore not marked with __THROW.