Function libnotcurses_sys::c_api::ffi::wcsspn
source · pub unsafe extern "C" fn wcsspn(
__wcs: *const wchar_t,
__accept: *const wchar_t
) -> usizeExpand description
Return the length of the initial segmet of WCS which consists entirely of wide characters in ACCEPT.