Struct libnotcurses_sys::c_api::ffi::ncmenu_item
source · [−]Expand description
Menus. Horizontal menu bars are supported, on the top and/or bottom rows. If the menu bar is longer than the screen, it will be only partially visible. Menus may be either visible or invisible by default. In the event of a plane resize, menus will be automatically moved/resized. Elements can be dynamically enabled or disabled at all levels (menu, section, and item),
Fields
desc: *const c_charutf-8 menu item, NULL for horizontal separator
shortcut: ncinputshortcut, all should be distinct
Implementations