Struct libnotcurses_sys::c_api::ffi::notcurses_options
source · [−]#[repr(C)]pub struct notcurses_options {
pub termtype: *const c_char,
pub loglevel: ncloglevel_e,
pub margin_t: c_uint,
pub margin_r: c_uint,
pub margin_b: c_uint,
pub margin_l: c_uint,
pub flags: u64,
}Expand description
Configuration for notcurses_init().
Fields
termtype: *const c_charThe name of the terminfo database entry describing this terminal. If NULL, the environment variable TERM is used. Failure to open the terminal definition will result in failure to initialize notcurses.
loglevel: ncloglevel_eProgressively higher log levels result in more logging to stderr. By default, nothing is printed to stderr once fullscreen service begins.
margin_t: c_uintDesirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).
margin_r: c_uintDesirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).
margin_b: c_uintDesirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).
margin_l: c_uintDesirable margins. If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can–this is strictly best-effort. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).
flags: u64General flags; see NCOPTION_*. This is expressed as a bitfield so that future options can be added without reshaping the struct. Undefined bits must be set to 0.
Implementations
sourceimpl notcurses_options
impl notcurses_options
sourcepub fn with_margins(top: u32, right: u32, bottom: u32, left: u32) -> Self
pub fn with_margins(top: u32, right: u32, bottom: u32, left: u32) -> Self
New NcOptions, with margins.
sourcepub fn with_flags(flags: impl Into<NcFlag>) -> Self
pub fn with_flags(flags: impl Into<NcFlag>) -> Self
New NcOptions, with flags.
sourcepub fn with_all_options(
loglevel: impl Into<NcLogLevel>,
margin_t: u32,
margin_r: u32,
margin_b: u32,
margin_l: u32,
flags: impl Into<NcFlag>
) -> Self
pub fn with_all_options(
loglevel: impl Into<NcLogLevel>,
margin_t: u32,
margin_r: u32,
margin_b: u32,
margin_l: u32,
flags: impl Into<NcFlag>
) -> Self
New NcOptions, with all the options.
Arguments
-
loglevel
Progressively higher log levels result in more logging to stderr. By default, nothing is printed to stderr once fullscreen service begins.
-
margin_t, margin_r, margin_b, margin_l
Desirable margins (top, right, bottom, left).
If all are 0 (default), we will render to the entirety of the screen. If the screen is too small, we do what we can. Absolute coordinates are relative to the rendering area ((0, 0) is always the origin of the rendering area).
-
flags
General flags; This is expressed as a bitfield so that future options can be added without reshaping the struct. Undefined bits must be set to 0.