Function libnotcurses_sys::c_api::ncdirect_cursor_push
source · pub unsafe extern "C" fn ncdirect_cursor_push(
n: *mut ncdirect
) -> c_intExpand description
Push or pop the cursor location to the terminal’s stack. The depth of this stack, and indeed its existence, is terminal-dependent.