Function libnotcurses_sys::c_api::ncdirect_hline_interp
source · pub fn ncdirect_hline_interp(
ncd: &mut NcDirect,
egc: &str,
len: u32,
h1: impl Into<NcChannels_u64>,
h2: impl Into<NcChannels_u64>
) -> NcResult_i32Expand description
Draws horizontal lines using the specified NcChannels_u64s, interpolating
between them as we go.
The string at egc may not use more than one column.
All lines start at the current cursor position.
For a horizontal line, len cannot exceed the screen width minus the
cursor’s offset.
Method: NcDirect.hline_interp().