Function libnotcurses_sys::c_api::ncmenu_unroll
source · [−]Expand description
Unroll the specified menu section, making the menu visible if it was invisible, and rolling up any menu section that is already unrolled.
Unroll the specified menu section, making the menu visible if it was invisible, and rolling up any menu section that is already unrolled.