Function libnotcurses_sys::c_api::ncpile_render_to_file
source · pub unsafe extern "C" fn ncpile_render_to_file(
p: *mut ncplane,
fp: *mut FILE
) -> c_intExpand description
Write the last rendered frame, in its entirety, to ‘fp’. If a frame has not yet been rendered, nothing will be written.