Function libnotcurses_sys::c_api::ncplane_cursor_y
source · [−]Expand description
Returns the current row of the cursor within this NcPlane.
Method: NcPlane.gradient().
Returns the current row of the cursor within this NcPlane.
Method: NcPlane.gradient().