Function libnotcurses_sys::c_api::nctree_focused
source · [−]Expand description
Return the focused item, if any items are present. This is not a copy; be careful to use it only for the duration of a critical section.
Return the focused item, if any items are present. This is not a copy; be careful to use it only for the duration of a critical section.