Struct libnotcurses_sys::c_api::ncinput [−][src]
#[repr(C)]pub struct ncinput {
pub id: u32,
pub y: c_int,
pub x: c_int,
pub utf8: [c_char; 5],
pub alt: bool,
pub shift: bool,
pub ctrl: bool,
pub evtype: ncinput__bindgen_ty_1,
pub ypx: c_int,
pub xpx: c_int,
}Expand description
An input event. Cell coordinates are currently defined only for mouse events. It is not guaranteed that we can set the modifiers for a given ncinput. We encompass single Unicode codepoints, not complete EGCs.
Fields
id: u32Unicode codepoint or synthesized NCKEY event
y: c_inty/x cell coordinate of event, -1 for undefined
x: c_inty/x cell coordinate of event, -1 for undefined
utf8: [c_char; 5]utf8 representation, if one exists
alt: boolwas alt held?
shift: boolwas shift held?
ctrl: boolwas ctrl held?
evtype: ncinput__bindgen_ty_1ypx: c_intpixel offsets within cell, -1 for undefined
xpx: c_intpixel offsets within cell, -1 for undefined
Implementations
New NcInput with shift key.