Struct libnotcurses_sys::c_api::ncmselector_item
source · [−]#[repr(C)]pub struct ncmselector_item {
pub option: *const c_char,
pub desc: *const c_char,
pub selected: bool,
}Fields
option: *const c_chardesc: *const c_charselected: boolTrait Implementations
sourceimpl Debug for ncmselector_item
impl Debug for ncmselector_item
sourceimpl Default for ncmselector_item
impl Default for ncmselector_item
sourceimpl Hash for ncmselector_item
impl Hash for ncmselector_item
sourceimpl Ord for ncmselector_item
impl Ord for ncmselector_item
sourceimpl PartialEq<ncmselector_item> for ncmselector_item
impl PartialEq<ncmselector_item> for ncmselector_item
sourcefn eq(&self, other: &ncmselector_item) -> bool
fn eq(&self, other: &ncmselector_item) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ncmselector_item) -> bool
fn ne(&self, other: &ncmselector_item) -> bool
This method tests for !=.
sourceimpl PartialOrd<ncmselector_item> for ncmselector_item
impl PartialOrd<ncmselector_item> for ncmselector_item
sourcefn partial_cmp(&self, other: &ncmselector_item) -> Option<Ordering>
fn partial_cmp(&self, other: &ncmselector_item) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ncmselector_item
impl StructuralEq for ncmselector_item
impl StructuralPartialEq for ncmselector_item