Struct libnotcurses_sys::c_api::ncreader_options
source · [−]Fields
tchannels: u64channels used for input
tattrword: u32attributes used for input
flags: u64bitfield of NCREADER_OPTION_*
Implementations
sourceimpl ncreader_options
impl ncreader_options
sourcepub const CURSOR: u32
pub const CURSOR: u32
Makes the terminal cursor visible across the lifetime of the ncreader, and have the ncreader manage the cursor’s placement.
sourcepub const HORSCROLL: u32
pub const HORSCROLL: u32
Enables horizontal scrolling. Virtual lines can then grow arbitrarily long.