Struct libnotcurses_sys::c_api::ncreader_options [−][src]
Fields
tchannels: u64channels used for input
tattrword: u32attributes used for input
flags: u64bitfield of NCREADER_OPTION_*
Implementations
Makes the terminal cursor visible across the lifetime of the ncreader, and have the ncreader manage the cursor’s placement.
Enables horizontal scrolling. Virtual lines can then grow arbitrarily long.
Disables all editing shortcuts. By default, emacs-style keys are available.