Struct libnotcurses_sys::c_api::ncreel_options
source · [−]#[repr(C)]pub struct ncreel_options {
pub bordermask: c_uint,
pub borderchan: u64,
pub tabletmask: c_uint,
pub tabletchan: u64,
pub focusedchan: u64,
pub flags: u64,
}Fields
bordermask: c_uintbitfield; 1s will not be drawn (see bordermaskbits)
borderchan: u64attributes used for ncreel border
tabletmask: c_uintbitfield; same as bordermask but for tablet borders
tabletchan: u64tablet border styling channel
focusedchan: u64focused tablet border styling channel
flags: u64bitfield over NCREEL_OPTION_*
Implementations
sourceimpl ncreel_options
impl ncreel_options
sourcepub const CIRCULAR: u32 = 2u32
pub const CIRCULAR: u32 = 2u32
is navigation circular (does moving down from the last tablet move to the first, and vice versa)? only meaningful when infinitescroll is true. if infinitescroll is false, this must be false.
sourcepub const INFINITESCROLL: u32 = 1u32
pub const INFINITESCROLL: u32 = 1u32
is scrolling infinite (can one move down or up forever, or is an end reached?). if true, ‘circular’ specifies how to handle the special case of an incompletely-filled reel.