Struct libnotcurses_sys::c_api::ncselector_item [−][src]
selection widget – an ncplane with a title header and a body section. the body section supports infinite scrolling up and down.
At all times, exactly one item is selected.
Fields
option: *const c_chardesc: *const c_charImplementations