Struct libnotcurses_sys::c_api::ncstats [−][src]
#[repr(C)]pub struct ncstats {Show 36 fields
pub renders: u64,
pub writeouts: u64,
pub failed_renders: u64,
pub failed_writeouts: u64,
pub raster_bytes: u64,
pub raster_max_bytes: i64,
pub raster_min_bytes: i64,
pub render_ns: u64,
pub render_max_ns: i64,
pub render_min_ns: i64,
pub raster_ns: u64,
pub raster_max_ns: i64,
pub raster_min_ns: i64,
pub writeout_ns: u64,
pub writeout_max_ns: i64,
pub writeout_min_ns: i64,
pub cellelisions: u64,
pub cellemissions: u64,
pub fgelisions: u64,
pub fgemissions: u64,
pub bgelisions: u64,
pub bgemissions: u64,
pub defaultelisions: u64,
pub defaultemissions: u64,
pub refreshes: u64,
pub sprixelemissions: u64,
pub sprixelelisions: u64,
pub sprixelbytes: u64,
pub appsync_updates: u64,
pub input_errors: u64,
pub input_events: u64,
pub hpa_gratuitous: u64,
pub cell_geo_changes: u64,
pub pixel_geo_changes: u64,
pub fbbytes: u64,
pub planes: c_uint,
}Expand description
whenever a new field is added here, ensure we add the proper rule to notcurses_stats_reset(), so that values are preserved in the stash stats.
Fields
renders: u64successful ncpile_render() runs
writeouts: u64successful ncpile_rasterize() runs
failed_renders: u64aborted renders, should be 0
failed_writeouts: u64aborted writes
raster_bytes: u64bytes emitted to ttyfp
raster_max_bytes: i64max bytes emitted for a frame
raster_min_bytes: i64min bytes emitted for a frame
render_ns: u64nanoseconds spent rendering
render_max_ns: i64max ns spent in render for a frame
render_min_ns: i64min ns spent in render for a frame
raster_ns: u64nanoseconds spent rasterizing
raster_max_ns: i64max ns spent in raster for a frame
raster_min_ns: i64min ns spent in raster for a frame
writeout_ns: u64nanoseconds spent writing frames to terminal
writeout_max_ns: i64max ns spent writing out a frame
writeout_min_ns: i64min ns spent writing out a frame
cellelisions: u64cells we elided entirely thanks to damage maps
cellemissions: u64total number of cells emitted to terminal
fgelisions: u64RGB fg elision count
fgemissions: u64RGB fg emissions
bgelisions: u64RGB bg elision count
bgemissions: u64RGB bg emissions
defaultelisions: u64default color was emitted
defaultemissions: u64default color was elided
refreshes: u64refresh requests (non-optimized redraw)
sprixelemissions: u64sprixel draw count
sprixelelisions: u64sprixel elision count
sprixelbytes: u64sprixel bytes emitted
appsync_updates: u64how many application-synchronized updates?
input_errors: u64errors processing control sequences/utf8
input_events: u64characters returned to userspace
hpa_gratuitous: u64unnecessary hpas issued
cell_geo_changes: u64cell geometry changes (resizes)
pixel_geo_changes: u64pixel geometry changes (font resize)
fbbytes: u64total bytes devoted to all active framebuffers
planes: c_uintnumber of planes currently in existence
Implementations