Type Definition libnotcurses_sys::c_api::NcLogLevel_i32
source · pub type NcLogLevel_i32 = ncloglevel_e;Expand description
Log level for NcOptions.
It’s recommended to use NcLogLevel instead.
Associated c_api constants
NCLOGLEVEL_SILENTNCLOGLEVEL_PANICNCLOGLEVEL_FATALNCLOGLEVEL_ERRORNCLOGLEVEL_WARNINGNCLOGLEVEL_INFONCLOGLEVEL_VERBOSENCLOGLEVEL_DEBUGNCLOGLEVEL_TRACE
These log levels consciously map cleanly to those of libav; notcurses itself
does not use this full granularity. The log level does not affect the opening
and closing banners, which can be disabled via the NcOptions
NCOPTION_SUPPRESS_BANNERS.
Note that if stderr is connected to the same terminal on which we’re rendering, any kind of logging will disrupt the output.