Type Definition libnotcurses_sys::c_api::NcVGeom
source · pub type NcVGeom = ncvgeom;Expand description
Describes all geometries of an NcVisual.
Both those which are inherent, and those dependent upon a given rendering regime.
It’s recommended to use NcVisualGeometry instead.
The inner values are calculated at the time of the call, and a font
change could make all the fields invalid, except for pixx/pixy.
This type is created by the ncvisual_geom & ncdirectf_geom
functions.