#[repr(i32)]pub enum NcLogLevel {
Silent = -1,
Panic = 0,
Fatal = 1,
Error = 2,
Warning = 3,
Info = 4,
Verbose = 5,
Debug = 6,
Trace = 7,
}Expand description
Log level for NcOptions.
Default
These log levels consciously map cleanly to those of libav; notcurses itself does not use this full granularity.
The log level does not affect the opening and closing banners,
which can be disabled via NcFlag::SuppressBanners
Note that if stderr is connected to the same terminal on which we’re rendering, any kind of logging will disrupt the output.
Variants
Silent = -1
Default. print nothing once fullscreen service begins.
Panic = 0
Print diagnostics immediately related to crashing.
Fatal = 1
We’re hanging around, but we’ve had a horrible fault.
Error = 2
We can’t keep doin’ this, but we can do other things.
Warning = 3
You probably don’t want what’s happening to happen.
Info = 4
“Standard information”.
Verbose = 5
“Detailed information”.
Debug = 6
This is honestly a bit much.
Trace = 7
There’s probably a better way to do what you want.