Enum libnotcurses_sys::NcLogLevel
source · [−]#[repr(i32)]
pub enum NcLogLevel {
Silent,
Panic,
Fatal,
Error,
Warning,
Info,
Verbose,
Debug,
Trace,
}Expand description
Log level for NcOptions.
Default
These log levels consciously map cleanly to those of libav; notcurses itself does not use this full granularity.
The log level does not affect the opening and closing banners,
which can be disabled via NcFlag::SuppressBanners
Note that if stderr is connected to the same terminal on which we’re rendering, any kind of logging will disrupt the output.
Variants
Silent
Default. print nothing once fullscreen service begins.
Panic
Print diagnostics immediately related to crashing.
Fatal
We’re hanging around, but we’ve had a horrible fault.
Error
We can’t keep doin’ this, but we can do other things.
Warning
You probably don’t want what’s happening to happen.
Info
“Standard information”.
Verbose
“Detailed information”.
Debug
This is honestly a bit much.
Trace
There’s probably a better way to do what you want.