Struct libnotcurses_sys::NcFile
source · [−]pub struct NcFile { /* private fields */ }Expand description
A wrapper struct around
libc::FILE
The notcurses’ FILE type is a transparent
struct, while the equivalent libc’s FILE is an opaque enum.
Several methods are provided to cast back and forth between both types,
in order to allow both rust libc operations and notcurses file operations
over the same underlying *FILE.
Implementations
sourceimpl NcFile
impl NcFile
sourcepub const RANDOM_ACCESS_MODE: &'static str
pub const RANDOM_ACCESS_MODE: &'static str
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data. It will not create the file if it does not exist.
sourcepub const UPDATE: &'static str
pub const UPDATE: &'static str
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data
sourcepub const READ_ONLY: &'static str
pub const READ_ONLY: &'static str
Intended to be passed into the CFile::open method. It will only allow reading.
sourcepub const WRITE_ONLY: &'static str
pub const WRITE_ONLY: &'static str
Intended to be passed into the CFile::open method. It will only allow writing.
sourcepub const APPEND_ONLY: &'static str
pub const APPEND_ONLY: &'static str
Intended to be passed into the CFile::open method. It will only allow data to be appended to the end of the file.
sourcepub const APPEND_READ: &'static str
pub const APPEND_READ: &'static str
Intended to be passed into the CFile::open method. It will allow data to be appended to the end of the file, and data to be read from the file. It will create the file if it doesn’t exist.
sourcepub const TRUNCATE_RANDOM_ACCESS_MODE: &'static str
pub const TRUNCATE_RANDOM_ACCESS_MODE: &'static str
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data. It will create the file if it doesn’t exist
sourceimpl NcFile
impl NcFile
sourcepub fn as_libc_ptr(&self) -> *mut FILE
pub fn as_libc_ptr(&self) -> *mut FILE
Returns the file pointer in the format expected by the libc crate.
sourcepub fn as_nc_ptr(&self) -> *mut FILE
pub fn as_nc_ptr(&self) -> *mut FILE
Returns the file pointer in the format expected by notcurses.
sourcepub fn current_pos(&self) -> Result<u64, Error>
pub fn current_pos(&self) -> Result<u64, Error>
Returns the current position in the file.
On error Error::Errno(errno) is returned.