Struct libnotcurses_sys::NcFile [−][src]
pub struct NcFile { /* fields omitted */ }Expand description
A wrapper struct around
libc::FILE
The notcurses’ FILE type is a transparent
struct, while the equivalent libc’s FILE is an opaque enum.
Several methods are provided to cast back and forth between both types,
in order to allow both rust libc operations and notcurses file operations
over the same underlying *FILE.
Implementations
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data. It will not create the file if it does not exist.
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data
Intended to be passed into the CFile::open method. It will only allow reading.
Intended to be passed into the CFile::open method. It will only allow writing.
Intended to be passed into the CFile::open method. It will only allow data to be appended to the end of the file.
Intended to be passed into the CFile::open method. It will allow data to be appended to the end of the file, and data to be read from the file. It will create the file if it doesn’t exist.
Intended to be passed into the CFile::open method. It will open the file in a way that will allow reading and writing, including overwriting old data. It will create the file if it doesn’t exist
Returns the file pointer in the format expected by the libc crate.
Returns the file pointer in the format expected by notcurses.
Returns the current position in the file.
On error Error::Errno(errno) is returned.