Struct libnotcurses_sys::NcFlag
source · [−]pub struct NcFlag(pub NcFlag_u64);Expand description
Tuple Fields
0: NcFlag_u64Implementations
sourceimpl NcFlag
impl NcFlag
sourcepub const DrainInput: Self
pub const DrainInput: Self
Input may be freely dropped.
This ought be provided when the program does not intend to handle input. Otherwise, input can accumulate in internal buffers, eventually preventing Notcurses from processing terminal messages.
sourcepub const InhibitSetLocale: Self
pub const InhibitSetLocale: Self
Do not call setlocale().
notcurses_init() will call setlocale() to inspect the current locale. If that locale is “C” or “POSIX”, it will call setlocale(LC_ALL, “”) to set the locale according to the LANG environment variable. Ideally, this will result in UTF8 being enabled, even if the client app didn’t call setlocale() itself. Unless you’re certain that you’re invoking setlocale() prior to notcurses_init(), you should not set this bit. Even if you are invoking setlocale(), this behavior shouldn’t be an issue unless you’re doing something weird (setting a locale not based on LANG).
sourcepub const NoAlternateScreen: Self
pub const NoAlternateScreen: Self
Do not enter alternate mode.
If smcup/rmcup capabilities are indicated, notcurses defaults to making use of the “alternate screen”. This flag inhibits use of smcup/rmcup.
sourcepub const NoClearBitmaps: Self
pub const NoClearBitmaps: Self
Do not try to clear any preexisting bitmaps.
Note that they might still get cleared even if this is set, and they might not get cleared even if this is not set.
sourcepub const NoFontChanges: Self
pub const NoFontChanges: Self
Do not modify the font.
Notcurses might attempt to change the font slightly, to support certain glyphs (especially on the Linux console). If this is set, no such modifications will be made. Note that font changes will not affect anything but the virtual console/terminal in which notcurses is running.
sourcepub const NoQuitSigHandlers: Self
pub const NoQuitSigHandlers: Self
Do not handle SIGINT, SIGSEGV, SIGABRT, SIGQUIT.
A signal handler will usually be installed for SIGABRT, SIGBUS,
SIGFPE, SIGILL, SIGINT, SIGQUIT, SIGSEGV and SIGTERM,
cleaning up the terminal on such exceptions.
With this flag, the handler will not be installed.
sourcepub const NoWinchSigHandler: Self
pub const NoWinchSigHandler: Self
Do not handle SIGWINCH.
A signal handler will usually be installed for SIGWINCH, resulting in
Nckey::Resize events being generated on input. With this flag,
the handler will not be installed.
sourcepub const PreserveCursor: Self
pub const PreserveCursor: Self
Initializes the standard plane’s virtual cursor to match the physical cursor at context creation time.
Together with NoAlternateScreen and a scrolling standard plane,
this facilitates easy scrolling-style programs in rendered mode.
sourcepub const Scrolling: Self
pub const Scrolling: Self
Prepares the standard plane in scrolling mode, useful for CLIs. This is
equivalent to calling ncplane_set_scrolling(notcurses_stdplane(nc), true).
sourcepub const CliMode: Self
pub const CliMode: Self
“CLI mode” is just setting these four options:
NoAlternateScreen
| NoClearBitmaps
| PreserveCursor
| Scrolling
sourcepub const SuppressBanners: Self
pub const SuppressBanners: Self
Do not print banners.
Notcurses typically prints version info in notcurses_init and
performance info in notcurses_stop. This inhibits that output.