Trait libnotcurses_sys::NcDirectFlagsApi [−][src]
pub trait NcDirectFlagsApi {
const DRAIN_INPUT: u64;
const INHIBIT_CBREAK: NcDirectFlags;
const INHIBIT_SETLOCALE: NcDirectFlags;
const NO_QUIT_SIGHANDLERS: NcDirectFlags;
const VERBOSE: NcDirectFlags;
const VERY_VERBOSE: NcDirectFlags;
}Expand description
Enables the NcDirectFlags associated methods and constants.
Associated Constants
const DRAIN_INPUT: u64
const DRAIN_INPUT: u64
Input may be freely dropped.
This ought be provided when the program does not intend to handle input. Otherwise, input can accumulate in internal buffers, eventually preventing Notcurses from processing terminal messages.
const INHIBIT_CBREAK: NcDirectFlags
const INHIBIT_CBREAK: NcDirectFlags
Flag that avoids placing the terminal into cbreak mode (disabling echo and line buffering)
Flag that avoids calling setlocale(LC_ALL, NULL)
If the result is either “C” or “POSIX”, it will print a diagnostic to stderr, and then call setlocale(LC_ALL, “”).
This will attempt to set the locale based off the LANG environment variable. Your program should call setlocale(3) itself, usually as one of the first lines.
Flag that inhibits registration of the SIGABRT, SIGBUS, SIGFPE,
SIGILL, SIGINT, SIGQUIT, SIGSEGV and SIGTERM, signal handlers.
const VERBOSE: NcDirectFlags
const VERBOSE: NcDirectFlags
Flag that enables showing detailed information.
const VERY_VERBOSE: NcDirectFlags
const VERY_VERBOSE: NcDirectFlags
Flag that enables showing all diagnostics (equivalent to
NcLogLevel::TRACE).
Implies NcDirectFlags::VERBOSE.