pub type NcOptions = notcurses_options;
Options struct for Nc.

Fields

Implementations

Returns a default Nc options builder.

Returns a builder object from the current Nc options.

New NcOptions.

New NcOptions, with margins.

New NcOptions, with flags.

New NcOptions, with flags

Returns the (top, right, bottom, left) margins.

Returns the log level.

Returns true if it has the DrainInput flag set.

Returns true if it has the InhibitSetLocale flag set.

Returns true if it has the NoAlternateScreen flag set.

Returns true if it has the NoClearBitmaps flag set.

Returns true if it has the NoFontChanges flag set.

Returns true if it has the NoQuitSigHandlers flag set.

Returns true if it has the NoWinchSigHandler flag set.

Returns true if it has the PreserveCursor flag set.

Returns true if it has the Scrolling flag set.

Returns true if it has the CliMode flag set.

Returns true if it has the SuppressBanners flag set.