Struct libnotcurses_sys::widgets::NcSelectorBuilder[][src]

pub struct NcSelectorBuilder { /* fields omitted */ }
A handy builder for NcSelector.

Implementations

New NcSelectorBuilder.

Adds an item.

Selects the default item

It is selected at the start and must be between 0 and itemcount-1.

Selects the maximum number of items to display at once.

0 uses all available space.

Sets the title string.

Sets the secondary title string.

Sets the footer string.

Sets the flags.

Sets all the NcChannels.

Sets the NcChannels for the item.

Sets the NcChannels for the title.

Sets the NcChannels for the secondary title and the footer.

Sets the NcChannels for the box title.

Finishes the builder and returns the NcSelector.