Struct libnotcurses_sys::widgets::NcSelectorBuilder [−][src]
pub struct NcSelectorBuilder { /* fields omitted */ }Expand description
A handy builder for NcSelector.
Implementations
Selects the default item
It is selected at the start and must be between 0 and itemcount-1.
Selects the maximum number of items to display at once.
0 uses all available space.
Sets the footer string.
pub fn all_channels(
self,
item_opt: NcChannels,
item_desc: NcChannels,
seltitle: NcChannels,
selfooter: NcChannels,
selbox: NcChannels
) -> Self
pub fn all_channels(
self,
item_opt: NcChannels,
item_desc: NcChannels,
seltitle: NcChannels,
selfooter: NcChannels,
selbox: NcChannels
) -> Self
Sets all the NcChannels.
Sets the NcChannels for the item.
Sets the NcChannels for the title.
Sets the NcChannels for the secondary title and the footer.
Sets the NcChannels for the box title.
Finishes the builder and returns the NcSelector.