Type Definition libnotcurses_sys::widgets::NcMenuOptions
source · pub type NcMenuOptions = ncmenu_options;Expand description
Options struct for NcMenu.
Implementations
sourceimpl NcMenuOptions
impl NcMenuOptions
sourcepub fn new(sections: &mut [NcMenuSection]) -> Self
pub fn new(sections: &mut [NcMenuSection]) -> Self
New NcMenuOptions for NcMenu.
sections must contain at least 1 NcMenuSection.
sourcepub fn with_all_args<CHS1, CHS2>(
sections: &mut [NcMenuSection],
style_header: CHS1,
style_sections: CHS2,
flags: u64
) -> Selfwhere
CHS1: Into<NcChannels>,
CHS2: Into<NcChannels>,
pub fn with_all_args<CHS1, CHS2>( sections: &mut [NcMenuSection], style_header: CHS1, style_sections: CHS2, flags: u64 ) -> Selfwhere CHS1: Into<NcChannels>, CHS2: Into<NcChannels>,
New NcMenuOptions for NcMenu, with all args.
sections must contain at least 1 NcMenuSection.
sourceimpl NcMenuOptions
impl NcMenuOptions
sourcepub fn header_channels(&self) -> NcChannels
pub fn header_channels(&self) -> NcChannels
Returns the styling for the header.
(No equivalent C style function)
sourcepub fn header_channels_mut(&mut self) -> &mut NcChannels_u64
pub fn header_channels_mut(&mut self) -> &mut NcChannels_u64
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
sourcepub fn section_channels(&self) -> NcChannels
pub fn section_channels(&self) -> NcChannels
Returns the styling for the sections.
(No equivalent C style function)
sourcepub fn section_channels_mut(&mut self) -> &mut NcChannels_u64
pub fn section_channels_mut(&mut self) -> &mut NcChannels_u64
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
sourceimpl NcMenuOptions
impl NcMenuOptions
sourcepub const BOTTOM: u64 = 1u64
pub const BOTTOM: u64 = 1u64
NcMenuOptions flag: Bottom row (as opposed to top row).
sourcepub const HIDING: u64 = 2u64
pub const HIDING: u64 = 2u64
NcMenuOptions flag: Hides the menu when not unrolled.