Type Definition libnotcurses_sys::widgets::NcMenuOptions[][src]

pub type NcMenuOptions = ncmenu_options;
Options struct for NcMenu.

Implementations

New NcMenuOptions for NcMenu.

sections must contain at least 1 NcMenuSection.

New NcMenuOptions for NcMenu, with all args.

sections must contain at least 1 NcMenuSection.

Returns the styling for the header.

(No equivalent C style function)

Returns a mutable reference of the styling for the sections.

(No equivalent C style function)

Returns the styling for the sections.

(No equivalent C style function)

Returns a mutable reference of the styling for the sections.

(No equivalent C style function)

NcMenuOptions flag: Bottom row (as opposed to top row).

NcMenuOptions flag: Hides the menu when not unrolled.