Type Definition libnotcurses_sys::widgets::NcMenuOptions [−][src]
pub type NcMenuOptions = ncmenu_options;Expand description
Options struct for NcMenu.
Implementations
New NcMenuOptions for NcMenu.
sections must contain at least 1 NcMenuSection.
pub fn with_all_args(
sections: &mut [NcMenuSection],
style_header: NcChannels,
style_sections: NcChannels,
flags: u64
) -> Self
pub fn with_all_args(
sections: &mut [NcMenuSection],
style_header: NcChannels,
style_sections: NcChannels,
flags: u64
) -> Self
New NcMenuOptions for NcMenu, with all args.
sections must contain at least 1 NcMenuSection.
Returns the styling for the header.
(No equivalent C style function)
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
Returns the styling for the sections.
(No equivalent C style function)
Returns a mutable reference of the styling for the sections.
(No equivalent C style function)
NcMenuOptions flag: Bottom row (as opposed to top row).
NcMenuOptions flag: Hides the menu when not unrolled.