Type Definition libnotcurses_sys::widgets::NcReaderOptions
source · pub type NcReaderOptions = ncreader_options;Expand description
Options struct for NcReader
type in C: ncreader_options (struct)
Implementations
sourceimpl NcReaderOptions
impl NcReaderOptions
sourcepub const CURSOR: u32 = 8u32
pub const CURSOR: u32 = 8u32
Makes the terminal cursor visible across the lifetime of the ncreader, and have the ncreader manage the cursor’s placement.
sourcepub const HORSCROLL: u32 = 1u32
pub const HORSCROLL: u32 = 1u32
Enables horizontal scrolling. Virtual lines can then grow arbitrarily long.