Type Definition libnotcurses_sys::widgets::NcReaderOptions[][src]

pub type NcReaderOptions = ncreader_options;
Options struct for NcReader

type in C: ncreader_options (struct)

Implementations

NcReaderOptions simple constructor.

Makes the terminal cursor visible across the lifetime of the ncreader, and have the ncreader manage the cursor’s placement.

Enables horizontal scrolling. Virtual lines can then grow arbitrarily long.

Disables all editing shortcuts. By default, emacs-style keys are available.

Enables vertical scrolling. You can then use arbitrarily many virtual lines.