Type Definition libnotcurses_sys::widgets::NcReelOptions

source ·
pub type NcReelOptions = ncreel_options;
Options struct for NcReel

Implementations

source

impl NcReelOptions

source

pub const CIRCULAR: u32 = 2u32

is navigation circular (does moving down from the last tablet move to the first, and vice versa)? only meaningful when infinitescroll is true. if infinitescroll is false, this must be false.

source

pub const INFINITESCROLL: u32 = 1u32

is scrolling infinite (can one move down or up forever, or is an end reached?). if true, ‘circular’ specifies how to handle the special case of an incompletely-filled reel.