Type Definition libnotcurses_sys::widgets::NcReelOptions [−][src]
pub type NcReelOptions = ncreel_options;Expand description
Options struct for NcReel
Implementations
is navigation circular (does moving down from the last tablet move to the first, and vice versa)? only meaningful when infinitescroll is true. if infinitescroll is false, this must be false.
is scrolling infinite (can one move down or up forever, or is an end reached?). if true, ‘circular’ specifies how to handle the special case of an incompletely-filled reel.